@@ -10,7 +10,7 @@ import base64
 import warnings
 import blowfish
 import logging
-import sqlite3
+import sys
 from sqlalchemy import create_engine
 from sqlalchemy.orm import sessionmaker
 from ..config import get_config
@@ -18,6 +18,14 @@ from ..utils import read_rekordbox6_asar
 from ..anlz import get_anlz_paths, read_anlz_files
 from . import tables
 
+if sys.platform.lower() == "darwin":
+    try:
+        from pysqlcipher3 import dbapi2 as sqlite3
+    except ImportError:
+        import sqlite3
+else:
+    import sqlite3
+
 logger = logging.getLogger(__name__)
 
 rb6_config = get_config("rekordbox6")
@@ -230,7 +238,7 @@ class Rekordbox6Database:
         return self.query(tables.DjmdProperty).filter_by(**kwargs)
 
     def get_related_tracks(self, **kwargs):
-        return self.query(tables.DjmdProperty).filter_by(**kwargs)
+        return self.query(tables.DjmdRelatedTracks).filter_by(**kwargs)
 
     def get_related_tracks_songs(self, id_):
         return self.query(tables.DjmdSongRelatedTracks).filter_by(RelatedTracksID=id_)
